================
 zope.container
================

.. image:: https://travis-ci.org/zopefoundation/zope.container.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.container

.. image:: https://readthedocs.org/projects/zopecontainer/badge/?version=latest
        :target: http://zopecontainer.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

This package define interfaces of container components, and provides
container implementations such as a :class:`~.BTreeContainer` and
:class:`~.OrderedContainer`, as well as the base class used by :mod:`zope.site.folder`
for the :class:`~.Folder` implementation.


Contents:

.. toctree::
   :maxdepth: 2

   narrative
   constraints
   api
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
